.. _webassets: https://github.com/miracle2k/webassets
.. _Jinja2: https://jinja.palletsprojects.com/
.. _Babel: http://babel.pocoo.org/


Optimus
=======

Optimus is a static site builder, it produces HTML from templates (through `Jinja2`_)
with assets management (through `webassets`_) and i18n support for translations
(through `Babel`_).


Links
*****

* Read the documentation on `Read the docs <https://optimus.readthedocs.io/>`_;
* Download its `PyPi package <https://pypi.python.org/pypi/Optimus>`_;
* Clone it on its `Github repository <https://github.com/sveetch/Optimus>`_;
